<?php

namespace Drupal\Tests\pdf_using_mpdf\Functional;

/**
 * Functional tests class.
 *
 * @package Drupal\Tests\pdf_using_mpdf\Functional
 */
class PdfUsingMpdfOutputTest extends PdfUsingMpdfTestBase {

  /**
   * Tests if output is a PDF file.
   *
   * Only for the case when PDF is generated and displayed on the browser.
   */
  public function testOutput() {
    $this->drupalLogin($this->adminUser);
    $this->drupalGet('admin/people/permissions');
    $this->submitForm(['authenticated[generate type_a pdf]' => TRUE], 'Save permissions');
    $this->assertSession()->pageTextContains('The changes have been saved.');

    $node_type_a = $this->createNode(['type' => 'type_a']);
    $this->drupalGet('node/' . $node_type_a->id() . '/pdf');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->responseHeaderContains('Content-Type', 'application/pdf');

    $this->drupalGet('admin/config/user-interface/mpdf');
    $this->submitForm(['pdf_save_option' => 1], 'Save configuration');
    $this->assertSession()->pageTextContains('The configuration options have been saved.');

    $this->drupalGet('node/' . $node_type_a->id() . '/pdf');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->responseHeaderContains('Content-Type', 'application/pdf');

    $this->drupalGet('admin/config/user-interface/mpdf');
    $this->submitForm(['pdf_save_option' => 2, 'pdf_save_schema' => 'public'], 'Save configuration');
    $this->assertSession()->pageTextContains('The configuration options have been saved.');

    $this->drupalGet('node/' . $node_type_a->id() . '/pdf');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->pageTextContains('saved to');
    $this->assertSession()->pageTextContains('/pdf_using_mpdf/');

    $this->drupalGet('admin/config/user-interface/mpdf');
    $this->submitForm(['pdf_save_path' => 'pdf_using_mpdf-test'], 'Save configuration');
    $this->assertSession()->pageTextContains('The configuration options have been saved.');

    $this->drupalGet('node/' . $node_type_a->id() . '/pdf');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->pageTextContains('saved to');
    $this->assertSession()->pageTextContains('/pdf_using_mpdf-test/');

    $this->drupalGet('admin/config/user-interface/mpdf');
    $this->submitForm(['pdf_filename' => 'http://www.example.org/äß'], 'Save configuration');
    $this->assertSession()->pageTextContains('The configuration options have been saved.');

    $this->drupalGet('node/' . $node_type_a->id() . '/pdf');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->pageTextContains('PDF file httpwwwexampleorgass.pdf saved to');

  }

}
